@@ -98,7 +98,9 @@ class FluxAgent:
 
     def run(self):
         if self.enable_local_fileserver:
-            self.loop.create_task(self.start_site(self.app, self.local_fileserver_port))
+            self.loop.create_task(
+                self.start_site(self.app, port=self.local_fileserver_port)
+            )
             self.log.info(
                 f"Local file server running on port {self.local_fileserver_port}"
             )
@@ -140,7 +142,7 @@ class FluxAgent:
 
         # We only accept connections from local network. (Protect against punter
         # exposing the fileserver port on the internet)
-        if not ipaddress.ip_address(request.remote).is_private():
+        if not ipaddress.ip_address(request.remote).is_private:
             return web.Response(
                 body="Unauthorized",
                 status=403,
